@@ -32,7 +32,7 @@ fi
 CONF="--conf-file=gm-from-vcs.conf"
 
 # options useful for development and debugging:
-TS=`date +%m_%d-%H_%M_%S`
+TS=$(date +%m_%d-%H_%M_%S)
 DEV_OPTS="--log-file=gm-vcs-${TS}-$$.log --override-schema-check --local-import --debug"
 #DEV_OPTS="${DEV_OPTS} --tool=check_mimetypes_in_archive"
 #DEV_OPTS="${DEV_OPTS} --tool=check_enc_epi_xref"
@@ -50,24 +50,24 @@ TARBALL_OPTS="--local-import --debug"
 export PYTHONIOENCODING=utf-8:surrogateescape
 # - devel version:
 echo "-------------------------------------------------"
-echo "Running from Git branch: "`git branch | grep \*`
+echo "Running from Git branch: $(git branch | grep \*)"
 echo "-------------------------------------------------"
 echo "config file: ${CONF}"
 #echo "options: ${DEV_OPTS}"
-#python3.7 gnumed.py ${CONF} ${DEV_OPTS} $@
-#python3.7 gnumed.py ${CONF} ${DEV_OPTS} $@ |& tee gm-vcs-console_output.log
-#python3.7 gnumed.py ${CONF} ${DEV_OPTS} $@
+#python3.7 gnumed.py ${CONF} ${DEV_OPTS} "$@"
+#python3.7 gnumed.py ${CONF} ${DEV_OPTS} "$@" |& tee gm-vcs-console_output.log
+#python3.7 gnumed.py ${CONF} ${DEV_OPTS} "$@"
 
 
 # - *released* tarball version:
 echo "options: ${TARBALL_OPTS}"
-python3 gnumed.py ${CONF} ${TARBALL_OPTS} $@
+python3 gnumed.py ${CONF} ${TARBALL_OPTS} "$@"
 
 # - production version (does not use tarball files !):
-#python3 gnumed.py $@
+#python3 gnumed.py "$@"
 
 # - production version with HIPAA support (does not use tarball files !):
-#python3 gnumed.py --hipaa $@
+#python3 gnumed.py --hipaa "$@"
 
 
 # source systemwide shutdown extension shell script if it exists
