@@ -543,7 +543,7 @@ class cMatchProvider_SQL2(cMatchProvider):
 		return matches
 
 	#--------------------------------------------------------
-	def _find_matches(self, fragment_condition):
+	def _find_matches(self, fragment_condition:str) -> tuple[bool, list]:
 		"""Loads matching data from PostgreSQL and turns them into
 		   matches fit for consumption by a phrasewheel.
 		"""
@@ -584,6 +584,7 @@ class cMatchProvider_SQL2(cMatchProvider):
 				rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': self._args}], get_col_idx = False)
 			except gmPG2.PG_ERROR_EXCEPTION:
 				_log.exception('[%s]: error running match provider SQL, dropping query', self.__class__.__name__)
+				_log.error('SQL: %s', cmd)
 				idx = self._queries.index(query)
 				del self._queries[idx]
 				break
