@@ -56,7 +56,7 @@ except ImportError:
 import psycopg2.errorcodes as sql_error_codes
 import psycopg2.sql as psysql
 
-PG_ERROR_EXCEPTION = dbapi.Error
+PG_ERROR_EXCEPTION = dbapi.DatabaseError
 
 # =======================================================================
 default_database = 'gnumed_v22'
@@ -373,51 +373,256 @@ def request_login_params(setup_pool=False):
 # =======================================================================
 # netadata API
 # =======================================================================
+SQL__pg_temp_concat_table_structure_v19_and_up = """
+create or replace function pg_temp.concat_table_structure_v19_and_up()
+	returns text
+	language 'plpgsql'
+	security definer
+	as '
+declare
+	_table_desc record;
+	_pk_desc record;
+	_column_desc record;
+	_constraint_def record;
+	_total text;
+begin
+	_total := '''';
+	-- find relevant tables
+	for _table_desc in
+		select * from information_schema.tables tabs where
+			tabs.table_schema in (''dem'', ''clin'', ''blobs'', ''cfg'', ''ref'', ''i18n'', ''bill'')
+				and
+			tabs.table_type = ''BASE TABLE''
+		order by
+			decode(md5(tabs.table_schema || tabs.table_name), ''hex'')
+	-- loop over tables
+	loop
+		-- where are we at ?
+		_total := _total || ''TABLE:'' || _table_desc.table_schema || ''.'' || _table_desc.table_name || E''\n'';
+		-- find PKs of that table
+		for _pk_desc in
+			select * from (
+				select
+					pg_class.oid::regclass || ''.'' || pg_attribute.attname || ''::'' || format_type(pg_attribute.atttypid, pg_attribute.atttypmod) AS primary_key_column
+				from
+					pg_index, pg_class, pg_attribute
+				where
+					--pg_class.oid = ''TABLENAME''::regclass
+					pg_class.oid = (_table_desc.table_schema || ''.'' || _table_desc.table_name)::regclass
+						AND 
+					indrelid = pg_class.oid
+						AND
+					pg_attribute.attrelid = pg_class.oid
+						AND
+					pg_attribute.attnum = any(pg_index.indkey)
+						AND
+					indisprimary
+				) AS PKs
+			order by
+				decode(md5(PKs.primary_key_column), ''hex'')
+		-- and loop over those PK columns
+		loop
+			_total := _total || ''PK:'' || _pk_desc.primary_key_column	|| E''\n'';
+		end loop;
+
+		-- find columns of that table
+		for _column_desc in
+			select *
+			from information_schema.columns cols
+			where
+				cols.table_name = _table_desc.table_name
+					and
+				cols.table_schema = _table_desc.table_schema
+			order by
+				decode(md5(cols.column_name || cols.data_type), ''hex'')
+		-- and loop over those columns
+		loop
+			-- add columns in the format "schema.table.column::data_type"
+			_total := _total || ''COL:''
+				|| _column_desc.table_schema || ''.''
+				|| _column_desc.table_name || ''.''
+				|| _column_desc.column_name || ''::''
+				|| _column_desc.udt_name || E''\n'';
+
+		end loop;
+		-- find and loop over CONSTRAINTs of that table
+		for _constraint_def in
+			select * from
+				(select
+					tbl.contype,
+					''CONSTRAINT:type=''
+						|| tbl.contype::TEXT || '':''
+						|| replace(pg_catalog.pg_get_constraintdef(tbl.oid, true), '' '', ''_'')
+						|| ''::active=''
+						|| tbl.convalidated::TEXT
+					 as condef
+				from pg_catalog.pg_constraint tbl
+				where
+					tbl.conrelid = (_table_desc.table_schema || ''.'' || _table_desc.table_name)::regclass
+					-- include FKs only because we may have to add/remove
+					-- other (say, check) constraints in a minor release
+					-- for valid reasons which we do not want to affect
+					-- the hash, if however we need to modify a foreign
+					-- key that would, indeed, warrant a hash change
+						AND
+					tbl.contype = ''f''
+				) as CONSTRAINTs
+			order by
+				CONSTRAINTs.contype,
+				decode(md5(CONSTRAINTs.condef), ''hex'')
+		loop
+			_total := _total || _constraint_def.condef || E''\n'';
+		end loop;
+	end loop;		-- over tables
+	return _total;
+end;';
+"""
+SQL__get_pg_temp_table_structure = "select pg_temp.concat_table_structure_v19_and_up();"
+SQL__md5_pg_temp_table_structure = "select md5(pg_temp.concat_table_structure_v19_and_up()) AS md5;"
+
+#------------------------------------------------------------------------
 def database_schema_compatible(link_obj=None, version=None, verbose=True):
 	expected_hash = known_schema_hashes[version]
-	if version == 0:
-		args = {'ver': 9999}
-	else:
-		args = {'ver': version}
-	rows, idx = run_ro_queries (
-		link_obj = link_obj,
-		queries = [{
-			'cmd': 'select md5(gm.concat_table_structure(%(ver)s::integer)) as md5',
-			'args': args
-		}]
-	)
-	if rows[0]['md5'] != expected_hash:
-		_log.error('database schema version mismatch')
-		_log.error('expected: %s (%s)' % (version, expected_hash))
-		_log.error('detected: %s (%s)' % (get_schema_version(link_obj=link_obj), rows[0]['md5']))
-		if verbose:
-			_log.debug('schema dump follows:')
-			for line in get_schema_structure(link_obj = link_obj).split():
-				_log.debug(line)
-			_log.debug('schema revision history dump follows:')
-			for line in get_schema_revision_history(link_obj = link_obj):
-				_log.debug(' - '.join(line))
-		return False
-	_log.info('detected schema version [%s], hash [%s]' % (map_schema_hash2version[rows[0]['md5']], rows[0]['md5']))
-	return True
+	ver = 9999 if version == 0 else version
+	md5_db = get_schema_hash(link_obj = link_obj, version = ver)
+	if md5_db == expected_hash:
+		_log.info('detected schema version [%s], hash [%s]' % (map_schema_hash2version[md5_db], md5_db))
+		return True
+
+	_log.error('database schema version mismatch')
+	_log.error('expected: %s (%s)' % (version, expected_hash))
+	try:
+		_log.error('detected: %s (%s)', map_schema_hash2version[md5_db], md5_db)
+	except KeyError:
+		_log.error('detected: <unknown> (%s)', md5_db)
+	if verbose:
+		log_schema_structure(link_obj = link_obj)
+		log_schema_revision_history(link_obj = link_obj)
+	return False
 
 #------------------------------------------------------------------------
 def get_schema_version(link_obj=None):
-	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': 'select md5(gm.concat_table_structure()) as md5'}])
+	md5_db = get_schema_hash(link_obj = link_obj)
+	if not md5_db:
+		_log.error('cannot determine schema version')
+		return None
+
 	try:
-		return map_schema_hash2version[rows[0]['md5']]
+		return map_schema_hash2version[md5_db]
+
 	except KeyError:
-		return 'unknown database schema version, MD5 hash is [%s]' % rows[0]['md5']
+		return 'unknown database schema version, MD5 hash is [%s]' % md5_db
+
+#------------------------------------------------------------------------
+def __get_schema_structure_by_gm_func(link_obj=None) -> str:
+	SQL = 'select gm.concat_table_structure()'
+	try:
+		rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': SQL}])
+		return rows[0][0]
+
+	except dbapi.errors.AmbiguousFunction as exc:
+		if hasattr(exc, 'diag') and 'gm.concat_table_structure_v19_and_up()' in exc.diag.context:
+			_log.error('gm.concat_table_structure_v19_and_up() failed')
+			return None
+
+		gmConnectionPool.log_pg_exception_details(exc)
+		raise
+
+#------------------------------------------------------------------------
+def __get_schema_structure_by_pg_temp_func() -> str:
+	queries = [
+		{'cmd': SQL__pg_temp_concat_table_structure_v19_and_up},
+		{'cmd': SQL__get_pg_temp_table_structure}
+	]
+	conn = get_connection(readonly = False)
+	try:
+		rows, idx = run_rw_queries(link_obj = conn, queries = queries, return_data = True)
+		return rows[0][0]
+
+	except PG_ERROR_EXCEPTION as exc:
+		_log.error('pg_temp.concat_table_structure_v19_and_up() failed')
+		gmConnectionPool.log_pg_exception_details(exc)
+		raise
+
+	finally:
+		conn.rollback()
+		conn.close()
+
+	# should never get here
+	return None
 
 #------------------------------------------------------------------------
 def get_schema_structure(link_obj=None):
-	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': 'select gm.concat_table_structure()'}])
-	return rows[0][0]
+	schema_struct = __get_schema_structure_by_gm_func(link_obj = link_obj)
+	if not schema_struct:
+		_log.debug('retrying with temporary function')
+		schema_struct = __get_schema_structure_by_pg_temp_func()
+	return schema_struct
 
 #------------------------------------------------------------------------
-def get_schema_hash(link_obj=None):
-	rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': 'select md5(gm.concat_table_structure()) as md5'}])
-	return rows[0]['md5']
+def log_schema_structure(link_obj=None):
+	_log.debug('schema structure dump:')
+	schema_struct = get_schema_structure(link_obj = link_obj)
+	if not schema_struct:
+		_log.error('cannot determine schema structure')
+		return
+
+	for line in schema_struct.split():
+		_log.debug(line)
+
+#------------------------------------------------------------------------
+def __get_schema_hash_by_gm_func(link_obj=None, version=None) -> str:
+	args = {}
+	if version:
+		SQL = 'SELECT md5(gm.concat_table_structure(%(ver)s::INTEGER)) AS md5'
+		args['ver'] = version
+	else:
+		SQL = 'SELECT md5(gm.concat_table_structure()) AS md5'
+	_log.debug('version: %s', version)
+	try:
+		rows, idx = run_ro_queries(link_obj=link_obj, queries = [{'cmd': SQL, 'args': args}])
+		_log.debug('hash: %s', rows[0]['md5'])
+		return rows[0]['md5']
+
+	except dbapi.errors.AmbiguousFunction as exc:
+		if hasattr(exc, 'diag') and 'gm.concat_table_structure_v19_and_up()' in exc.diag.context:
+			_log.error('gm.concat_table_structure_v19_and_up() failed')
+			return None
+
+		gmConnectionPool.log_pg_exception_details(exc)
+		raise
+
+#------------------------------------------------------------------------
+def __get_schema_hash_by_pg_temp_func() -> str:
+	conn = get_connection(readonly = False)
+	queries = [
+		{'cmd': SQL__pg_temp_concat_table_structure_v19_and_up},
+		{'cmd': SQL__md5_pg_temp_table_structure}
+	]
+	try:
+		rows, idx = run_rw_queries(link_obj = conn, queries = queries, return_data = True)
+		_log.debug('hash: %s', rows[0]['md5'])
+		return rows[0]['md5']
+
+	except PG_ERROR_EXCEPTION as exc:
+		_log.error('pg_temp.concat_table_structure_v19_and_up() failed')
+		gmConnectionPool.log_pg_exception_details(exc)
+		raise
+
+	finally:
+		conn.rollback()
+		conn.close()
+
+	# should never get here
+	return None
+
+#------------------------------------------------------------------------
+def get_schema_hash(link_obj=None, version=None):
+	md5_db = __get_schema_hash_by_gm_func(link_obj = link_obj)
+	if not md5_db:
+		_log.debug('retrying with temporary function')
+		md5_db = __get_schema_hash_by_pg_temp_func()
+	return md5_db
 
 #------------------------------------------------------------------------
 def get_schema_revision_history(link_obj=None):
@@ -444,6 +649,12 @@ def get_schema_revision_history(link_obj=None):
 	rows, idx = run_ro_queries(link_obj = link_obj, queries = [{'cmd': cmd}])
 	return rows
 
+#------------------------------------------------------------------------
+def log_schema_revision_history(link_obj=None):
+	_log.debug('schema revision history dump:')
+	for line in get_schema_revision_history(link_obj = link_obj):
+		_log.debug(' - '.join(line))
+
 #------------------------------------------------------------------------
 def get_db_fingerprint(conn=None, fname=None, with_dump=False, eol=None):
 	queries = [
@@ -479,23 +690,31 @@ def get_db_fingerprint(conn=None, fname=None, with_dump=False, eol=None):
 	rows = curs.fetchall()
 	lines.append('%20s: %s' % ('Size (DB)', rows[0][0]))
 	# get hash
-	cmd = "SELECT md5(gm.concat_table_structure())"
-	curs.execute(cmd)
-	rows = curs.fetchall()
-	md5_sum = rows[0][0]
+	md5_sum = get_schema_hash(link_obj = curs)
 	try:
 		lines.append('%20s: %s (v%s)' % ('Schema hash', md5_sum, map_schema_hash2version[md5_sum]))
 	except KeyError:
 		lines.append('%20s: %s' % ('Schema hash', md5_sum))
 	for cmd, label in queries:
-		curs.execute(cmd)
-		rows = curs.fetchall()
-		lines.append('%20s: %s' % (label, rows[0][0]))
+		try:
+			curs.execute(cmd)
+			rows = curs.fetchall()
+			if rows:
+				val = rows[0][0]
+			else:
+				val = '<not found>'
+		except PG_ERROR_EXCEPTION as pg_exc:
+			if pg_exc.pgcode != sql_error_codes.INSUFFICIENT_PRIVILEGE:
+				raise
+
+			if pg_exc.pgerror is None:
+				val = '[%s]: insufficient privileges' % pg_exc.pgcode
+			else:
+				val = '[%s]: %s' % (pg_exc.pgcode, pg_exc.pgerror)
+		lines.append('%20s: %s' % (label, val))
 	if with_dump:
-		curs.execute('SELECT gm.concat_table_structure()')
-		rows = curs.fetchall()
 		lines.append('')
-		lines.append(rows[0][0])
+		lines.append(str(get_schema_structure(link_obj = curs)))
 	curs.close()
 	if fname is None:
 		if eol is None:
@@ -1634,7 +1853,7 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 				_log.exception('cannot rollback transaction')
 				gmConnectionPool.log_pg_exception_details(pg_exc2)
 			if pg_exc.pgcode == sql_error_codes.INSUFFICIENT_PRIVILEGE:
-				details = 'Query: [%s]' % curs.query.strip().strip('\n').strip().strip('\n')
+				details = 'Query: [%s]' % curs.query.decode(errors = 'replace').strip().strip('\n').strip().strip('\n')
 				if curs.statusmessage != '':
 					details = 'Status: %s\n%s' % (
 						curs.statusmessage.strip().strip('\n').strip().strip('\n'),
@@ -1790,7 +2009,7 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 				gmConnectionPool.log_pg_exception_details(pg_exc2)
 			# privilege problem
 			if pg_exc.pgcode == sql_error_codes.INSUFFICIENT_PRIVILEGE:
-				details = 'Query: [%s]' % curs.query.strip().strip('\n').strip().strip('\n')
+				details = 'Query: [%s]' % curs.query.decode(errors = 'replace').strip().strip('\n').strip().strip('\n')
 				if curs.statusmessage != '':
 					details = 'Status: %s\n%s' % (
 						curs.statusmessage.strip().strip('\n').strip().strip('\n'),
@@ -2007,7 +2226,7 @@ def sanity_check_time_skew(tolerance=60):
 	return True
 
 #-----------------------------------------------------------------------
-def sanity_check_database_settings():
+def sanity_check_database_settings(hipaa:bool=False) -> (int, str):
 	"""Checks database settings.
 
 	returns (status, message)
@@ -2044,12 +2263,9 @@ def sanity_check_database_settings():
 		'synchronous_commit': [['on'], 'data loss/corruption', False],
 		'sql_inheritance': [['on'], 'query breakage, data loss/corruption', True],	# IF returned (<PG10): better be ON, if NOT returned (PG10): hardwired
 		'ignore_checksum_failure': [['off'], 'data loss/corruption', False],		# starting with PG 9.3
-		'track_commit_timestamp': [['on'], 'suboptimal auditing', False]			# starting with PG 9.3
+		'track_commit_timestamp': [['on'], 'suboptimal auditing', False],			# starting with PG 9.3
 	}
-
-	from Gnumed.pycommon import gmCfg2
-	_cfg = gmCfg2.gmCfgData()
-	if _cfg.get(option = 'hipaa'):
+	if hipaa:
 		options2check['log_connections'] = [['on'], 'non-compliance with HIPAA', True]
 		options2check['log_disconnections'] = [['on'], 'non-compliance with HIPAA', True]
 	else:
@@ -2062,7 +2278,6 @@ def sanity_check_database_settings():
 		queries = [{'cmd': cmd, 'args': {'settings': tuple(options2check)}}],
 		get_col_idx = False
 	)
-
 	found_error = False
 	found_problem = False
 	msg = []
@@ -2082,9 +2297,21 @@ def sanity_check_database_settings():
 			else:
 				_log.error(options2check[option])
 				raise ValueError('invalid database configuration sanity check')
+
 			msg.append(_(' option [%s]: %s') % (option, value_found))
 			msg.append(_('  risk: %s') % risk)
 			_log.warning('PG option [%s] set to [%s], expected %s, risk: <%s>' % (option, value_found, values_expected, risk))
+#	SQL = "SELECT name, setting from pg_settings where name = 'shared_preload_libraries';"
+#	rows, idx = run_ro_queries (link_obj = conn, queries = [{'cmd': SQL, 'args': None}])
+#	if rows:
+#		value_found = rows[0]['setting']
+#	else:
+#		value_found = []
+#	if 'auto_explain' not in value_found:
+#		msg.append(_(' option [shared_preload_libraries]: %s') % value_found)
+#		msg.append(_('  risk: suboptimal debugging'))
+#		_log.warning('PG option [shared_preload_libraries] set to: %s, expected to include "auto_explain", risk: <suboptimal debugging>', value_found)
+#		found_problem = True
 
 	if found_error:
 		return 2, '\n'.join(msg)
@@ -2112,9 +2339,10 @@ if __name__ == "__main__":
 	if sys.argv[1] != 'test':
 		sys.exit()
 
-	from Gnumed.pycommon.gmTools import file2md5
+	#from Gnumed.pycommon.gmTools import file2md5
 
 	logging.basicConfig(level=logging.DEBUG)
+	gmLog2.print_logfile_name()
 
 	#--------------------------------------------------------------------
 	def test_file2bytea():
@@ -2398,6 +2626,13 @@ if __name__ == "__main__":
 
 		return status
 
+	#--------------------------------------------------------------------
+	def test_sanity_check_database_settings():
+		login, creds = request_login_params()
+		pool = gmConnectionPool.gmConnectionPool()
+		pool.credentials = creds
+		print(sanity_check_database_settings(hipaa = True))
+
 	#--------------------------------------------------------------------
 	def test_sanity_check_time_skew():
 		login, creds = request_login_params()
@@ -2595,6 +2830,37 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 		#print(get_db_fingerprint(conn, with_dump = True, eol = '\n'))
 		print(get_db_fingerprint(with_dump = True, eol = '\n'))
 
+	#--------------------------------------------------------------------
+	def test_schema_compatible():
+		request_login_params(setup_pool = True)
+		print(database_schema_compatible(version=22, verbose=True))
+
+	#--------------------------------------------------------------------
+	def test_get_schema_structure():
+		request_login_params(setup_pool = True)
+		print(get_schema_structure())
+
+	#--------------------------------------------------------------------
+	def test_pg_temp_concat():
+		request_login_params(setup_pool = True)
+		conn = get_connection(readonly = False)
+		queries = [
+			{'cmd': SQL__pg_temp_concat_table_structure_v19_and_up},
+			{'cmd': SQL__get_pg_temp_table_structure}
+		]
+		rows, idx = run_rw_queries(link_obj = conn, queries = queries, return_data = True)
+		conn.rollback()
+		conn.close()
+		print(rows[0][0])
+
+	#--------------------------------------------------------------------
+	def test___get_schema_structure():
+		request_login_params(setup_pool = True)
+		with open('x-gm_func.txt', 'w', encoding = 'utf8') as f:
+			f.write(__get_schema_structure_by_gm_func())
+		with open('x-pg_temp_func.txt', 'w', encoding = 'utf8') as f:
+			f.write(__get_schema_structure_by_pg_temp_func())
+
 	#--------------------------------------------------------------------
 	# run tests
 
@@ -2613,6 +2879,7 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 	#test_sanitize_pg_regex()
 	#test_is_pg_interval()
 	#test_sanity_check_time_skew()
+	#test_sanity_check_database_settings()
 	#test_get_foreign_key_details()
 	#test_get_index_name()
 	#test_set_user_language()
@@ -2620,9 +2887,13 @@ SELECT to_timestamp (foofoo,'YYMMDD.HH24MI') FROM (
 	#test_run_query()
 	#test_schema_exists()
 	#test_get_foreign_key_names()
-	test_row_locks()
+	#test_row_locks()
 	#test_faulty_SQL()
 	#test_log_settings()
-	#test_get_db_fingerprint()
+	test_get_db_fingerprint()
+	#test_schema_compatible()
+	#test_get_schema_structure()
+	#test___get_schema_structure()
+	#test_pg_temp_concat()
 
 # ======================================================================
