@@ -94,10 +94,20 @@ class TimelineScene(object):
     def get_closest_overlapping_event(self, selected_event, up=True):
         self._inflate_event_rects_to_get_right_dimensions_for_overlap_calculations()
         rect = self._get_event_rect(selected_event)
-        period = self._event_rect_drawn_as_period(rect)
-        direction = self._get_direction(period, up)
-        evt = self._get_overlapping_event(period, direction, selected_event, rect)
-        return (evt, direction)
+        # self._get_event_rect() returns None if the selected event isn't visible.
+        # (The selected event can be scrolled out of view). In this case the period
+        # can't be calculated and because of that the direction and event can't be
+        # calculated. Instead you get exceptions when trying to access rect attributes.
+        # To avoid this situation we return event=None when no rect is found. 
+        # The result on the GUI is that the event won't be moved vertically. And 
+        # that's better then an exception!
+        if rect is None: 
+            return (None, 1)
+        else:
+            period = self._event_rect_drawn_as_period(rect)
+            direction = self._get_direction(period, up)
+            evt = self._get_overlapping_event(period, direction, selected_event, rect)
+            return (evt, direction)
 
     def center_text(self):
         return self._appearance.get_center_event_texts()
@@ -274,7 +284,7 @@ class TimelineScene(object):
             ry = self._calc_y_pos_for_non_period_event(event, rh)
             if event.is_milestone():
                 rw = rh
-                rx = self._metrics.calc_x(event.get_time_period().start_time) - rw / 2
+                rx = self._metrics.calc_x(event.get_time_period().start_time) - rw // 2
                 return wx.Rect(rx, ry, rw, rh)
             return self._calc_ideal_wx_rect(rx, ry, rw, rh)
 
@@ -286,7 +296,7 @@ class TimelineScene(object):
         rw = tw + 2 * self._inner_padding + 2 * self._outer_padding
         rh = th + 2 * self._inner_padding + 2 * self._outer_padding
         if event.has_data():
-            rw += self._data_indicator_size / 3
+            rw += self._data_indicator_size // 3
         if event.get_fuzzy() or event.get_locked():
             rw += th + 2 * self._inner_padding
         return rw, rh
@@ -295,11 +305,11 @@ class TimelineScene(object):
         if self._appearance.get_draw_period_events_to_right():
             return self._metrics.calc_x(event.get_time_period().start_time) - self._outer_padding
         else:
-            return self._metrics.calc_x(event.mean_time()) - rw / 2
+            return self._metrics.calc_x(event.mean_time()) - rw // 2
 
     def _calc_y_pos_for_non_period_event(self, event, rh):
         if event.is_milestone():
-            return self._metrics.half_height - rh / 2
+            return self._metrics.half_height - rh // 2
         else:
             return self._metrics.half_height - rh - self._baseline_padding
 
