@@ -315,7 +315,7 @@ def mail_log(parent=None, comment=None, helpdesk=None, sender=None, exception=No
 	receivers = []
 	if helpdesk is not None:
 		receivers = regex.findall (
-			'[\S]+@[\S]+',
+			r'[\S]+@[\S]+',
 			helpdesk.strip(),
 			flags = regex.UNICODE
 		)
@@ -339,7 +339,7 @@ def mail_log(parent=None, comment=None, helpdesk=None, sender=None, exception=No
 		return
 
 	receivers = regex.findall (
-		'[\S]+@[\S]+',
+		r'[\S]+@[\S]+',
 		receiver_string,
 		flags = regex.UNICODE
 	)
