@@ -17,9 +17,7 @@ import wx
 
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-	_ = lambda x:x
 from Gnumed.pycommon import gmI18N
-#from Gnumed.wxpython import gmPlugin
 
 ID_SNELLENMENU = wx.NewId()
 ID_SNELLENBUTTON = wx.NewId()
@@ -261,7 +259,7 @@ class cSnellenChart(wx.Frame):
 	def OnPaint (self, event):
 		self.dc = wx.PaintDC(self)
 		if self.screen_width_pixel == 0:
-			self.screen_width_pixel, self.screen_height_pixel = self.GetClientSizeTuple()
+			self.screen_width_pixel, self.screen_height_pixel = self.GetClientSize()
 			self.set_distance(2)
 #			_log.info('I think the screen size is %d x %d' % (self.screen_width_pixel, self.screen_height_pixel))
 
@@ -305,10 +303,10 @@ class cSnellenChart(wx.Frame):
 		self.Refresh()
 
 	def OnDClick (self, key):
-		self.Destroy()
+		self.DestroyLater()
 		
 	def OnClose (self, event):
-		self.Destroy()
+		self.DestroyLater()
 
 	def DestroyWhenApp (self):
 		import sys
